@@ -52,10 +52,10 @@ SCANNER = re.Scanner([
     (r"\s", S_EMPTY),
     (r"(-?\d+(\.\d*)([eE][+\-]?\d+)?)", S_FLOAT),
     (r"string|boolean|null|array|object|number", S_TYPE),
-    (ur"\"([_a-zA-Z]|[^\0-\0177]|\\[^\s0-9a-fA-F])([_a-zA-Z0-9\-]" \
+    (ur"\"([_a-zA-Z]|[^\0-\0177]|\\[^\s0-9a-fA-F])([_a-zA-Z0-9\-]"
      ur"|[^\u0000-\u0177]|(\\[^\s0-9a-fA-F]))*\"", S_WORD),
     (r'\.?\"([^"\\]|\\[^"])*\"', S_QUOTED_IDENTIFIER),
-    (ur"\.([_a-zA-Z]|[^\0-\0177]|\\[^\s0-9a-fA-F])([_a-zA-Z0-9\-]" \
+    (ur"\.([_a-zA-Z]|[^\0-\0177]|\\[^\s0-9a-fA-F])([_a-zA-Z0-9\-]"
      ur"|[^\u0000-\u0177]|(\\[^\s0-9a-fA-F]))*", S_IDENTIFIER),
     (r":(root|empty|first-child|last-child|only-child)", S_PCLASS),
     (r":(has|expr|val|contains)", S_PCLASS_FUNC),
@@ -116,7 +116,8 @@ def lex(input, scanner=SCANNER):
     if not len(tokens):
         raise LexingError("no input parsed.")
     if len(rest):
-        raise LexingError("found leftover tokens: %s" % rest)
+        print tokens
+        raise LexingError("found leftover tokens: (%s, %s)" % (tokens, rest))
     return [tok for tok in tokens if tok[0] != 'empty']
 
 def lex_expr(expression):
@@ -211,7 +212,7 @@ class Parser(object):
             elif operator == ' ':
                 results = self.ancestors(results, rvals)
             else:
-                raise SelectorSyntaxError("unrecognized operator '%s'" \
+                raise SelectorSyntaxError("unrecognized operator '%s'"
                                           % operator)
         else:
             if len(tokens):
@@ -270,12 +271,12 @@ class Parser(object):
     def pclass_production(self, pclass):
         pclass_map = {
             'first-child': lambda node: node.idx == 1,
-            'last-child': lambda node: \
-                node.siblings and node.idx == node.siblings,
+            'last-child': lambda node: (node.siblings and
+                                        node.idx == node.siblings),
             'only-child': lambda node: node.siblings == 1,
             'root': lambda node: not node.parent,
-            'empty': lambda node: isinstance(node.value, list) and \
-                not len(node.value)
+            'empty': lambda node: (isinstance(node.value, list) and
+                                   not len(node.value))
         }
 
         try:
@@ -288,30 +289,30 @@ class Parser(object):
             return all([isinstance(arg, type_) for arg in args])
 
         cmpf_map = {
-            '*': lambda lhs, rhs: types_eq(numbers.Number, lhs, rhs) and \
-                lhs * rhs,
-            '/': lambda lhs, rhs: types_eq(numbers.Number, lhs, rhs) and \
-                lhs / rhs,
-            '%': lambda lhs, rhs: types_eq(numbers.Number, lhs, rhs) and \
-                lhs % rhs,
-            '+': lambda lhs, rhs: types_eq(numbers.Number, lhs, rhs) and \
-                lhs + rhs,
-            '-': lambda lhs, rhs: types_eq(numbers.Number, lhs, rhs) and \
-                lhs - rhs,
-            '<=': lambda lhs, rhs: types_eq(numbers.Number, lhs, rhs) and \
-                lhs <= rhs,
-            '<':  lambda lhs, rhs: types_eq(basestring, lhs, rhs) and \
-                lhs < rhs,
-            '>=': lambda lhs, rhs: types_eq(numbers.Number, lhs, rhs) and \
-                lhs >= rhs,
-            '>':  lambda lhs, rhs: types_eq(basestring, lhs, rhs) and \
-                lhs > rhs,
-            '$=': lambda lhs, rhs: types_eq(basestring, lhs, rhs) and \
-                lhs.rfind(rhs) == len(lhs) - len(rhs),
-            '^=': lambda lhs, rhs: types_eq(basestring, lhs, rhs) and \
-                lhs.find(rhs) == 0,
-            '*=': lambda lhs, rhs: types_eq(basestring, lhs, rhs) and \
-                lhs.find(rhs) != 0,
+            '*': lambda lhs, rhs: (types_eq(numbers.Number, lhs, rhs) and
+                                   lhs * rhs),
+            '/': lambda lhs, rhs: (types_eq(numbers.Number, lhs, rhs) and
+                                   lhs / rhs),
+            '%': lambda lhs, rhs: (types_eq(numbers.Number, lhs, rhs) and
+                                   lhs % rhs),
+            '+': lambda lhs, rhs: (types_eq(numbers.Number, lhs, rhs) and
+                                   lhs + rhs),
+            '-': lambda lhs, rhs: (types_eq(numbers.Number, lhs, rhs) and
+                                   lhs - rhs),
+            '<=': lambda lhs, rhs: (types_eq(numbers.Number, lhs, rhs) and
+                                    lhs <= rhs),
+            '<': lambda lhs, rhs: (types_eq(basestring, lhs, rhs) and
+                                   lhs < rhs),
+            '>=': lambda lhs, rhs: (types_eq(numbers.Number, lhs, rhs) and
+                                    lhs >= rhs),
+            '>': lambda lhs, rhs: (types_eq(basestring, lhs, rhs) and
+                                   lhs > rhs),
+            '$=': lambda lhs, rhs: (types_eq(basestring, lhs, rhs) and
+                                    lhs.rfind(rhs) == len(lhs) - len(rhs)),
+            '^=': lambda lhs, rhs: (types_eq(basestring, lhs, rhs) and
+                                    lhs.find(rhs) == 0),
+            '*=': lambda lhs, rhs: (types_eq(basestring, lhs, rhs) and
+                                    lhs.find(rhs) != 0),
             '=': lambda lhs, rhs: lhs == rhs,
             '!=': lambda lhs, rhs: lhs != rhs,
             '&&': lambda lhs, rhs: lhs and rhs,
@@ -319,6 +320,7 @@ class Parser(object):
         }
 
 # ((12 % 10) + 40 = x)
+
         def parse(tokens):
             if not len(tokens):
                 raise Exception
@@ -326,6 +328,7 @@ class Parser(object):
             if self.peek(tokens, 'paren') == '(':
                 self.match(tokens, 'paren')
                 lhs = parse(tokens)
+                return lhs
             elif self.peek(tokens, 'pvar') is not None:
                 self.match(tokens, 'pvar')
                 lhs = node.value
@@ -344,7 +347,7 @@ class Parser(object):
             rhs = parse(tokens)
 
             return cf(lhs, rhs)
-        
+
         return parse(tokens)
 
     def expr_production(self, args):
@@ -370,12 +373,12 @@ class Parser(object):
             return lambda node: node in ancestors
 
         if pclass == 'contains':
-            return lambda node: isinstance(node.value, basestring) and \
-                    node.value.find(args[0][1]) >= 0
+            return lambda node: (isinstance(node.value, basestring) and
+                                 node.value.find(args[0][1]) >= 0)
 
         if pclass == 'val':
-            return lambda node: isinstance(node.value, basestring) and \
-                    node.value == args[0][1]
+            return lambda node: (isinstance(node.value, basestring) and
+                                 node.value == args[0][1])
 
         raise SelectorSyntaxError("unsupported pclass function %s" % pclass)
 
@@ -439,8 +442,8 @@ class Parser(object):
 
     @staticmethod
     def match(tokens, type_):
-        if  Parser.peek(tokens, type_) is None:
-            raise Exception('match not successful')
+        if Parser.peek(tokens, type_) is None:
+            raise Exception('match not successful (%s, %s)' % (type_, tokens))
 
         token = tokens.pop(0)
         return token[1]
